@@ -29,10 +29,8 @@
        -- from http://www.ncbi.nlm.nih.gov/books/NBK25497/, March 2013
 
 """
-import json
 from bioservices import REST
-from bioservices import __version__
-from bioservices import logger
+from bioservices import logger, version
 
 logger.name = __name__
 
@@ -98,17 +96,16 @@ class EUtils:
 
     """
 
-    def __init__(
-        self, verbose=False, email="unknown", cache=False, xmlparser="EUtilsParser"
-    ):
+    def __init__(self, verbose=False, email="unknown", cache=False, xmlparser="EUtilsParser"):
 
         self.services = REST(
             name="EUtils",
-            url = "https://eutils.ncbi.nlm.nih.gov/entrez/eutils",
+            url="https://eutils.ncbi.nlm.nih.gov/entrez/eutils",
             cache=cache,
             verbose=verbose,
-            requests_per_sec=3, 
-            url_defined_later=True)
+            requests_per_sec=3,
+            url_defined_later=True,
+        )
 
         warning = """
 
@@ -143,7 +140,7 @@ class EUtils:
         self._xmlparser = xmlparser
 
         self._databases = None
-        self.tool = "BioServices, " + __version__
+        self.tool = "BioServices, " + version
 
         #: fill this with your email address
         self.email = email
@@ -195,8 +192,7 @@ class EUtils:
                 # unknown so let use it but raise a warning
                 params[k] = v
                 self.services.logging.warning(
-                    "%s does not seem to be a known parameter. " % k
-                    + "Use it anyway but may be ignored"
+                    "%s does not seem to be a known parameter. " % k + "Use it anyway but may be ignored"
                 )
         return params
 
