@@ -1,5 +1,3 @@
-#!/usr/bin/python
-# -*- coding: latin-1 -*-
 #
 #  This file is part of bioservices software
 #
@@ -16,9 +14,7 @@
 #  documentation: http://packages.python.org/bioservices
 #
 ##############################################################################
-#$Id$
 """This module includes common tools to manipulate XML files"""
-from __future__ import print_function
 import xml.etree.ElementTree as ET
 import bs4
 
@@ -58,6 +54,7 @@ class easyXML(object):
     There is also aliases findAll and prettify.
 
     """
+
     def __init__(self, data, encoding="utf-8"):
         """.. rubric:: Constructor
 
@@ -72,10 +69,10 @@ class easyXML(object):
         have an URL instead, use :class:`readXML`
 
         """
-        #if fixing_unicode:
+        # if fixing_unicode:
         #    x = unicodefix.FixingUnicode(data, verbose=False, encoding=encoding)
         #    self.data = x.fixed_string.encode("utf-8")
-        #else:
+        # else:
         self.data = data[:]
 
         try:
@@ -97,6 +94,7 @@ class easyXML(object):
         if self._soup is None:
             self._soup = bs4.BeautifulSoup(self.data, "lxml")
         return self._soup
+
     soup = property(_get_soup, doc="Returns the beautiful soup instance")
 
     def __str__(self):
@@ -116,6 +114,7 @@ class readXML(easyXML):
     .. seealso:: :class:`easyXML`
 
     """
+
     def __init__(self, url, encoding="utf-8"):
         self.data = urlopen(url).read()
         super(readXML, self).__init__(self.data, encoding)
@@ -125,6 +124,7 @@ class XMLObjectify(object):
     def __init__(self, obj):
         """obj can be easyXML data set"""
         from lxml import objectify
+
         try:
             self.root = objectify.fromstring(obj.data)
         except:
